pub struct PowerDomain {
pub id: Option<u32>,
pub node_id: Option<u32>,
pub name: Option<String>,
}Expand description
Represents a single power domain configuration for a device.
Fields
id: Option<u32>node_id: Option<u32>name: Option<String>Trait Implementations
Sourceimpl Clone for PowerDomain
impl Clone for PowerDomain
Sourcefn clone(&self) -> PowerDomain
fn clone(&self) -> PowerDomain
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PowerDomain
impl Debug for PowerDomain
Sourceimpl Default for PowerDomain
impl Default for PowerDomain
Sourcefn default() -> PowerDomain
fn default() -> PowerDomain
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<PowerDomain<'static>, ___E> for &'a PowerDomainwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<PowerDomain<'static>, ___E> for &'a PowerDomainwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<PowerDomain<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<PowerDomain<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PowerDomain<'static>, ___E> for PowerDomainwhere
___E: Encoder + ?Sized,
impl<___E> Encode<PowerDomain<'static>, ___E> for PowerDomainwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<PowerDomain<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<PowerDomain<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<PowerDomain<'de>> for PowerDomain
impl<'de> FromWire<PowerDomain<'de>> for PowerDomain
Sourcefn from_wire(wire_: PowerDomain<'de>) -> Self
fn from_wire(wire_: PowerDomain<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PowerDomain<'de>> for PowerDomain
impl<'de> FromWireRef<PowerDomain<'de>> for PowerDomain
Sourcefn from_wire_ref(wire: &PowerDomain<'de>) -> Self
fn from_wire_ref(wire: &PowerDomain<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for PowerDomain
impl Hash for PowerDomain
Sourceimpl Ord for PowerDomain
impl Ord for PowerDomain
Sourcefn cmp(&self, other: &PowerDomain) -> Ordering
fn cmp(&self, other: &PowerDomain) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PowerDomain
impl PartialEq for PowerDomain
Sourcefn eq(&self, other: &PowerDomain) -> bool
fn eq(&self, other: &PowerDomain) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PowerDomain
impl PartialOrd for PowerDomain
impl Eq for PowerDomain
impl StructuralPartialEq for PowerDomain