#[repr(C)]pub struct DomainIsEnabledResponse {
pub enabled: bool,
}Expand description
The wire type corresponding to DomainIsEnabledResponse.
Fields
enabled: boolTrait Implementations
Sourceimpl Clone for DomainIsEnabledResponse
impl Clone for DomainIsEnabledResponse
Sourcefn clone(&self) -> DomainIsEnabledResponse
fn clone(&self) -> DomainIsEnabledResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DomainIsEnabledResponse
impl Constrained for DomainIsEnabledResponse
Sourceimpl Debug for DomainIsEnabledResponse
impl Debug for DomainIsEnabledResponse
Sourceimpl<___D> Decode<___D> for DomainIsEnabledResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DomainIsEnabledResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DomainIsEnabledResponse, ___E> for &'a DomainIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DomainIsEnabledResponse, ___E> for &'a DomainIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DomainIsEnabledResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DomainIsEnabledResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DomainIsEnabledResponse, ___E> for DomainIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DomainIsEnabledResponse, ___E> for DomainIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DomainIsEnabledResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DomainIsEnabledResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DomainIsEnabledResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DomainIsEnabledResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DomainIsEnabledResponse, ___E> for DomainIsEnabledResponse<T0>
impl<___E, T0> Encode<DomainIsEnabledResponse, ___E> for DomainIsEnabledResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DomainIsEnabledResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DomainIsEnabledResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DomainIsEnabledResponse> for DomainIsEnabledResponse
impl FromWire<DomainIsEnabledResponse> for DomainIsEnabledResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DomainIsEnabledResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DomainIsEnabledResponse, Self>
Sourcefn from_wire(wire: DomainIsEnabledResponse) -> Self
fn from_wire(wire: DomainIsEnabledResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DomainIsEnabledResponse> for DomainIsEnabledResponse
impl FromWireRef<DomainIsEnabledResponse> for DomainIsEnabledResponse
Sourcefn from_wire_ref(wire: &DomainIsEnabledResponse) -> Self
fn from_wire_ref(wire: &DomainIsEnabledResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DomainIsEnabledResponse
impl IntoNatural for DomainIsEnabledResponse
Sourcetype Natural = DomainIsEnabledResponse
type Natural = DomainIsEnabledResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DomainIsEnabledResponse
impl Wire for DomainIsEnabledResponse
Sourcetype Narrowed<'de> = DomainIsEnabledResponse
type Narrowed<'de> = DomainIsEnabledResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.